@@ -1,5 +1,6 @@
 from typing import Any
 from typing import Dict
+from typing import List
 
 STOP_ITERATION = object()
 
@@ -7,11 +8,11 @@ STOP_ITERATION = object()
 def __init__(hub):
     hub.evbus.STARTED = False
     hub.evbus.RUN_FOREVER = True
-    for dyne in ("acct", "ingress", "output", "serialize"):
+    for dyne in ("acct", "ingress", "output", "serialize", "match"):
         hub.pop.sub.add(dyne_name=dyne)
 
 
-async def start(hub, contexts: Dict[str, Dict[str, Any]]):
+async def start(hub, contexts: Dict[str, List[Dict[str, Any]]]):
     hub.log.debug("Starting event bus")
     hub.evbus.STARTED = True
 
